=======
Credits
=======

Development Lead
----------------

* Brian Torres-Gil <btorres-gil@paloaltonetworks.com>

Contributors
------------

Thank you to Kevin Steves, creator of the pan-python library.
https://github.com/kevinsteves/pan-python
